@@ -13,7 +13,6 @@ DEFAULT_CONFIG = {
     "SIGN_UP_INSTRUCTIONS": None,
     "SIGN_UP_ASK_SOCIAL_MEDIA": False,
     "PRIVACY_POLICY_PAGE": None,
-    "THREADPOOL_MAX_WORKERS": 2,
 }
 
 
@@ -23,8 +22,8 @@ def _read_if_html_path(txt: str) -> str:
     If the input is a path to a valid HTML file, read it.
     Otherwise return the input
     """
-    if txt and txt.endswith('.html'):
-        with open(txt, 'rt') as fh:
+    if txt and txt.endswith(".html"):
+        with open(txt, "rt") as fh:
             txt = fh.read()
     return txt
 
@@ -43,21 +42,26 @@ def generate_flask_config(config):
         The configuration for the RAMP worker.
     """
     if isinstance(config, str):
-        config = read_config(config, filter_section=['flask', 'sqlalchemy'])
+        config = read_config(config, filter_section=["flask", "sqlalchemy"])
 
     flask_config = DEFAULT_CONFIG.copy()
-    user_flask_config = {
-        key.upper(): value for key, value in config['flask'].items()}
+    user_flask_config = {key.upper(): value for key, value in config["flask"].items()}
     flask_config.update(user_flask_config)
 
-    for key in ['LOGIN_INSTRUCTIONS', 'SIGN_UP_INSTRUCTIONS',
-                'PRIVACY_POLICY_PAGE']:
+    for key in [
+        "LOGIN_INSTRUCTIONS",
+        "SIGN_UP_INSTRUCTIONS",
+        "PRIVACY_POLICY_PAGE",
+    ]:
         flask_config[key] = _read_if_html_path(flask_config[key])
 
-    database_config = config['sqlalchemy']
-    flask_config['SQLALCHEMY_DATABASE_URI'] = \
-        ('{}://{}:{}@{}:{}/{}'
-         .format(database_config['drivername'], database_config['username'],
-                 database_config['password'], database_config['host'],
-                 database_config['port'], database_config['database']))
+    database_config = config["sqlalchemy"]
+    flask_config["SQLALCHEMY_DATABASE_URI"] = "{}://{}:{}@{}:{}/{}".format(
+        database_config["drivername"],
+        database_config["username"],
+        database_config["password"],
+        database_config["host"],
+        database_config["port"],
+        database_config["database"],
+    )
     return flask_config
