@@ -9,8 +9,7 @@ from ramp_utils.frontend import _read_if_html_path
 
 @pytest.mark.parametrize(
     "config",
-    [database_config_template(),
-     read_config(database_config_template())]
+    [database_config_template(), read_config(database_config_template())],
 )
 def test_generate_flask_config(config):
     flask_config = generate_flask_config(config)
@@ -30,25 +29,24 @@ def test_generate_flask_config(config):
         "SIGN_UP_INSTRUCTIONS": None,
         "SQLALCHEMY_TRACK_MODIFICATIONS": False,
         "SQLALCHEMY_DATABASE_URI": (
-            "postgresql://mrramp:mrramp@localhost:5432/databoard_test"
+            "postgresql://mrramp:mrramp@localhost:5432" "/databoard_test"
         ),
         "TRACK_USER_INTERACTION": True,
         "TRACK_CREDITS": True,
         "DOMAIN_NAME": "localhost",
-        "THREADPOOL_MAX_WORKERS": 2,
     }
     assert flask_config == expected_config
 
 
 def test_read_if_html_path(tmpdir):
-    msg = 'some arbitrary text'
+    msg = "some arbitrary text"
     assert _read_if_html_path(msg) == msg
 
-    msg = 'an_ivalid_path.html'
+    msg = "an_ivalid_path.html"
     with pytest.raises(FileNotFoundError):
         _read_if_html_path(msg)
 
-    msg = str(tmpdir / 'some_file.html')
-    with open(msg, 'wt') as fh:
-        fh.write('Privacy Policy')
-    assert _read_if_html_path(msg) == 'Privacy Policy'
+    msg = str(tmpdir / "some_file.html")
+    with open(msg, "wt") as fh:
+        fh.write("Privacy Policy")
+    assert _read_if_html_path(msg) == "Privacy Policy"
